@@ -1,5 +1,3 @@
-/* $Id: command.c,v 1.19 2004/06/09 18:52:21 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -21,6 +19,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop/read.h>
 #include <glibtop/write.h>
 #include <glibtop/read_data.h>
@@ -31,13 +30,11 @@ void *
 glibtop_call_l (glibtop *server, unsigned command, size_t send_size,
 		const void *send_buf, size_t recv_size, void *recv_buf)
 {
-	glibtop_command cmnd;
-	glibtop_response response;
+	glibtop_command cmnd = {0};
+	glibtop_response response = {0};
 
 	glibtop_init_r (&server, 0, 0);
 
-	memset (&cmnd, 0, sizeof (glibtop_command));
-
 	cmnd.command = command;
 
 	/* If send_size is less than _GLIBTOP_PARAM_SIZE (normally 16 Bytes), we
